Learn R Programming

EpiLPS (version 1.3.0)

Rmodelpriors: Prior specification for model hyperparameters

Description

Specification of the hyperparameters for the Gamma prior on the roughness penalty parameter associated to the P-spline model and the Gamma prior on the overdispersion parameter of the negative binomial model underlying the incidence data.

Usage

Rmodelpriors(
  listcontrol = list(a_delta = 10, b_delta = 10, phi = 2, a_rho = 1e-04, b_rho = 1e-04)
)

Value

A list with the specified hyperparameter components. By default, \(a_{\delta} = b_{\delta} = 10\), \(\phi = 2\) and

\(a_{\rho}=b_{\rho}=10^{-4}\).

Arguments

listcontrol

A list specifying the hyperparameters in the Gamma priors for the roughness penalty parameter of the P-spline model (named \(a_{\delta}\), \(b_{\delta}\) and \(\phi\)) and the overdispersion parameter of the negative binomial model for the incidence data (named \(a_{\rho}\) and \(b_{\rho}\)).

Author

Oswaldo Gressani oswaldo_gressani@hotmail.fr

References

Gressani, O., Wallinga, J., Althaus, C. L., Hens, N. and Faes, C. (2022). EpiLPS: A fast and flexible Bayesian tool for estimation of the time-varying reproduction number. Plos Computational Biology, 18(10): e1010618.