A data frame with six columns including the calendar date of COVID-19 infection, the date on which cases have been reported and the number of cases.
data(cov19incidence2022)tA numeric variable associated to a calendar date.
dA numeric variable indicating the delay of reporting.
DateThe calendar date for incidence.
Rep.dateThe calendar date for the reporting of incidence.
CasesThe number of cases.
ReportedIndicates whether cases are already reported or not.