A data frame with six columns including the calendar date of death, the date on which cases have been reported and the number of cases/deaths.
data(cov19mort2021)tA numeric variable associated to a calendar date.
dA numeric variable indicating the delay of reporting.
DateThe calendar date of the death event.
Rep.dateThe calendar date for the reporting of the death event.
CasesThe number of cases/deaths.
ReportedIndicates whether cases are already reported or not.