Based on a serial interval and a functional input for the reproduction number over \(T\) days, the routine generates an incidence time series following a Poisson or negative binomial model. The link between the reproduction number and the generated incidence data is governed by the renewal equation. The baseline (mean) number of cases at day 1 is fixed at 10. The mean number of cases for the remaining days of the epidemic are generated following equation (2) of Azmon et al. (2013).
episim(si, endepi = 50, Rpattern = 1, Rconst = 2.5,
dist = c("poiss", "negbin"), overdisp = 1, verbose = FALSE, plotsim = FALSE)An object of class episim consisting of a list with the
generated incidence time series, the mean vector of the Poisson/negative binomial
distribution, the true underlying R function for the data generating process and the
chosen serial interval distribution.
The serial interval distribution.
The total number of days of the epidemic.
Different scenarios for the true underlying curve of Rt. Six scenarios are possible with 1,2,3,4,5,6.
The constant value of R (if scenario 1 is selected), default is 2.5.
The distribution from which to sample the incidence counts. Either Poisson (default) or negative binomial.
Overdispersion parameter for the negative binomial setting.
Should metadata of the simulated epidemic be printed?
Create a plot of the incidence time series, the true reproduction number curve and the serial interval.
Oswaldo Gressani oswaldo_gressani@hotmail.fr
Azmon, A., Faes, C., Hens, N. (2014). On the estimation of the reproduction number based on misreported epidemic data. Statistics in medicine, 33(7):1176-1192.
si <- c(0.05, 0.05, 0.1, 0.1, 0.1, 0.1, 0.1, 0.05, 0.05, 0.1, 0.1, 0.1)
epidemic <- episim(si = si, Rpattern = 1)
Run the code above in your browser using DataLab