Learn R Programming

EpiLPS (version 1.3.0)

sars2003: Daily incidence of the 2003 SARS epidemic in Hong Kong

Description

A list with the daily incidence of onset of symptoms for the 2003 SARS outbreak in Hong Kong and a discretized serial interval distribution.

Usage

data(sars2003)

Arguments

Format

A list with two components:

incidence

A vector with 107 observations.

si

A vector of probabilities corresponding to the serial interval distribution.

References

Cori A. et al. (2009). Temporal variability and social heterogeneity in disease transmission: the case of SARS in Hong Kong. Plos Computational Biology 5(8) : e1000471.