Learn R Programming

EpiLPS (version 1.3.0)

zika2015: Data on the 2015 Zika virus disease in Colombia

Description

A list containing incidence data for the 2015 Zika disease in Girardot (Colombia) from October 2015 to January 2016, a vector of dates and a discrete serial interval distribution.

Usage

data(zika2015)

Arguments

Format

A list with three components:

incidence

An incidence time series of length 93.

dates

A vector of dates in "YYYY-MM-DD" format.

si

A vector of probabilities corresponding to the serial interval distribution with a mean of 7 days and standard deviation of 1.5 days.

References

Rojas, D. P. et al. (2016). The epidemiology and transmissibility of Zika virus in Girardot and San Andres island, Colombia, September 2015 to January 2016. Eurosurveillance, 21(28), 30283.